@@ -8,10 +8,10 @@ import logging
 import sys
 import traceback
 
-from gordo.machine.dataset.data_provider.providers import NoSuitableDataProviderError
-from gordo.machine.dataset.sensor_tag import SensorTagNormalizationError
-from gordo.machine.dataset.base import InsufficientDataError, ConfigurationError
-from gordo.machine.dataset.exceptions import ConfigException
+from gordo_dataset.data_provider.providers import NoSuitableDataProviderError
+from gordo_dataset.sensor_tag import SensorTagNormalizationError
+from gordo_dataset.base import InsufficientDataError, ConfigurationError
+from gordo_dataset.exceptions import ConfigException
 from gunicorn.glogging import Logger
 from azure.datalake.store.exceptions import DatalakeIncompleteTransferException
 
